@@ -30,14 +30,19 @@ class Environment(object):
         self.system = System()
         self.logger = self.__build_logger(logger=logger, level=logging_level)
 
-    def install(self, raw_target_manifest, namespace=None):
+    def install(self, raw_target_manifest, namespace=None, username=None, password=None):
         """
         Install an environment based on the target manifest passed
         """
-        target_manifest = Manifest(raw_target_manifest, namespace=namespace)
+        if username or password:
+            assert (username and password), "both username and password required!!"
+        target_manifest = Manifest(raw_target_manifest,
+                                   namespace=namespace,
+                                   username=username,
+                                   password=password)
         directory = Directory(target_manifest.namespace)
         if not directory.new:
-            self.logger.info("Namespace %s already exists, updating..." % \
+            self.logger.info("Namespace %s already exists, updating..." %
                              target_manifest.namespace)
             self._update(Manifest(directory.manifest_path),
                          target_manifest,
@@ -46,10 +51,12 @@ class Environment(object):
             self.logger.info("Installing environment %s..." % target_manifest.namespace)
             self._install(target_manifest)
 
-    def update(self, namespace):
+    def update(self, namespace, username=None, password=None):
         """
         Update a namespace
         """
+        if username or password:
+            assert (username and password), "both username and password required!!"
         directory = Directory(namespace)
         if directory.new:
             self.logger.error("Namespace %s is not yet installed!" % namespace)
@@ -59,7 +66,7 @@ class Environment(object):
         if not source:
             self.logger.error("Installed manifest for %s has no source!" % namespace)
             return
-        target_manifest = Manifest(source, namespace=namespace)
+        target_manifest = Manifest(source, namespace=namespace, username=username, password=password)
         self.logger.info("Updating environment %s..." % target_manifest.namespace)
         self._update(source_manifest, target_manifest)
 
@@ -149,15 +156,17 @@ class Environment(object):
         self.initialize(target_manifest=target_manifest, directory=directory)
         self._run_setups()
         self.injections.inject("~/.bash_profile", "[ -d %s ] && . %s/.rc" %
-                (self.directory.root_dir, self.directory.root_dir))
+                               (self.directory.root_dir, self.directory.root_dir))
+        self.injections.inject("~/.bashrc", "[ -d %s ] && . %s/.rc" %
+                               (self.directory.root_dir, self.directory.root_dir))
         self.finalize()
 
     def _update(self, source_manifest, target_manifest, directory=None):
         """
         Intall an environment from a target manifest Manifest
         """
-        self.initialize(source_manifest=source_manifest, 
-                        target_manifest=target_manifest, 
+        self.initialize(source_manifest=source_manifest,
+                        target_manifest=target_manifest,
                         directory=directory)
         self._run_setups()
         self._run_updates()
@@ -190,7 +199,9 @@ class Environment(object):
         self.initialize(source_manifest=source_manifest, directory=directory)
         self._run_activates()
         self.injections.inject("~/.bash_profile", "[ -d %s ] && . %s/.rc" %
-                (self.directory.root_dir, self.directory.root_dir))
+                               (self.directory.root_dir, self.directory.root_dir))
+        self.injections.inject("~/.bashrc", "[ -d %s ] && . %s/.rc" %
+                               (self.directory.root_dir, self.directory.root_dir))
         self.finalize()
 
     def _reload(self, source_manifest, directory=None):
